@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine.h.in,v 1.144 2005/07/17 23:11:33 dsalt Exp $
+ * $Id: xine.h.in,v 1.149 2006/06/22 10:38:37 klan Exp $
  *
  * public xine-lib (libxine) interface and documentation
  *
@@ -113,8 +113,8 @@ int  xine_check_version (int major, int minor, int sub) ;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   0
-#define XINE_VERSION       "1.1.0"
+#define XINE_SUB_VERSION   2
+#define XINE_VERSION       "1.1.2"
 
 /*
  * pre-init the xine engine
@@ -338,6 +338,8 @@ int  xine_get_param (xine_stream_t *stream, int param);
 #define XINE_PARAM_AUDIO_CLOSE_DEVICE     28 /* force closing audio device  */
 #define XINE_PARAM_AUDIO_AMP_MUTE         29 /* 1=>mute, 0=>unmute */
 #define XINE_PARAM_FINE_SPEED             30 /* 1.000.000 => normal speed   */ 
+#define XINE_PARAM_EARLY_FINISHED_EVENT   31 /* send event when demux finish*/
+#define XINE_PARAM_GAPLESS_SWITCH         32 /* next stream only gapless swi*/ 
 
 /*
  * speed values for XINE_PARAM_SPEED parameter.
@@ -367,6 +369,8 @@ int  xine_get_param (xine_stream_t *stream, int param);
 #define XINE_PARAM_VO_ZOOM_Y               0x0100000d /* percent            */
 #define XINE_PARAM_VO_PAN_SCAN             0x01000009 /* bool               */
 #define XINE_PARAM_VO_TVMODE               0x0100000a /* ???                */
+#define XINE_PARAM_VO_WINDOW_WIDTH         0x0100000f /* readonly           */
+#define XINE_PARAM_VO_WINDOW_HEIGHT        0x01000010 /* readonly           */
 #define XINE_PARAM_VO_CROP_LEFT            0x01000020 /* crop frame pixels  */
 #define XINE_PARAM_VO_CROP_RIGHT           0x01000021 /* crop frame pixels  */
 #define XINE_PARAM_VO_CROP_TOP             0x01000022 /* crop frame pixels  */
@@ -1056,6 +1060,7 @@ const char *const *xine_list_video_decoder_plugins(xine_t *self);
 /* unload unused plugins */
 void xine_plugins_garbage_collector(xine_t *self);
 
+
 /*********************************************************************
  * visual specific gui <-> xine engine communication                 *
  *********************************************************************/
@@ -1522,9 +1527,16 @@ void xine_config_reset (xine_t *self);
 #define XINE_EVENT_VDR_VOLMINUS         330
 #define XINE_EVENT_VDR_MUTE             331
 #define XINE_EVENT_VDR_AUDIO            332
+#define XINE_EVENT_VDR_INFO             333
 /* some space for further keys */
 #define XINE_EVENT_VDR_SETVIDEOWINDOW   350
 #define XINE_EVENT_VDR_FRAMESIZECHANGED 351
+#define XINE_EVENT_VDR_SELECTAUDIO      352
+#define XINE_EVENT_VDR_TRICKSPEEDMODE   353
+#define XINE_EVENT_VDR_PLUGINSTARTED    354
+
+/* events generated from post plugins */
+#define XINE_EVENT_POST_TVTIME_FILMMODE_CHANGE   400
 
 /*
  * xine event struct
@@ -1881,7 +1893,7 @@ void        xine_osd_draw_line     (xine_osd_t *self, int x1, int y1,
 void        xine_osd_draw_rect     (xine_osd_t *self, int x1, int y1,
 				    int x2, int y2,
 				    int color, int filled );
-/*  x1 and y1 specifies the upper left corner of the text to be rendered */
+/* x1 and y1 specifies the upper left corner of the text to be rendered */
 void        xine_osd_draw_text     (xine_osd_t *self, int x1, int y1,
 				    const char *text, int color_base);
 void        xine_osd_draw_bitmap   (xine_osd_t *self, uint8_t *bitmap,
@@ -1918,10 +1930,10 @@ void        xine_osd_clear         (xine_osd_t *self);
  *
  * Use OSD_TEXT1, OSD_TEXT2, ... for some preassigned color indices.
  *
- * these palettes are not really well working the true type fonts.
- * First thing is that these fonts can not have a border. So the best
- * result you can get by loading a linearly blending palette from the
- * background (at index 0) to the forground color (at index 10)
+ * These palettes are not working well with the true type fonts.
+ * First thing is that these fonts cannot have a border. So you get
+ * the best results by loading a linearly blending palette from the
+ * background (at index 0) to the forground color (at index 10).
  */
 void        xine_osd_set_text_palette (xine_osd_t *self,
 				       int palette_number,
