@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: demux_elem.c,v 1.85.2.1 2005/04/20 17:21:03 mroi Exp $
+ * $Id: demux_elem.c,v 1.88 2006/06/02 22:18:56 dsalt Exp $
  *
  * demultiplexer for elementary mpeg streams
  */
@@ -301,11 +301,11 @@ static void *init_plugin (xine_t *xine, void *data) {
 /*
  * exported plugin catalog entry
  */
-demuxer_info_t demux_info_elem = {
+static const demuxer_info_t demux_info_elem = {
   0                       /* priority */
 };
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_DEMUX, 26, "elem", XINE_VERSION_CODE, &demux_info_elem, init_plugin },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
