@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: dvaudio_decoder.c,v 1.6 2004/12/16 13:58:57 mroi Exp $
+ * $Id: dvaudio_decoder.c,v 1.10 2006/06/02 22:13:45 dsalt Exp $
  *
  * dv audio decoder based on patch by Dan Dennedy <dan@dennedy.org>
  *
@@ -289,7 +289,7 @@ static void dvaudio_decode_data (audio_decoder_t *this_gen, buf_element_t *buf)
     if (!this->output_open) {
       this->output_open = this->stream->audio_out->open(this->stream->audio_out,
         this->stream, this->audio_bits, this->audio_sample_rate,
-        (this->audio_channels == 2) ? AO_CAP_MODE_STEREO : AO_CAP_MODE_MONO);
+	_x_ao_channels2mode(this->audio_channels));
     }
 
     /* if the audio still isn't open, bail */
@@ -433,7 +433,7 @@ static uint32_t supported_audio_types[] = {
   0
 };
 
-decoder_info_t dec_info_dvaudio = {
+static const decoder_info_t dec_info_dvaudio = {
   supported_audio_types,   /* supported types */
   5                        /* priority        */
 };
@@ -442,7 +442,7 @@ decoder_info_t dec_info_dvaudio = {
  * exported plugin catalog entry
  */
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_AUDIO_DECODER, 15, "dvaudio", XINE_VERSION_CODE, &dec_info_dvaudio, init_dvaudio_plugin },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
