@@ -34,7 +34,6 @@
  *   to 4096 byte boundaries on disk.
  */
 #include "config.h"
-//#include <wine/config.h>
 
 #include <errno.h>
 #include <assert.h>
@@ -48,13 +47,13 @@
 #ifdef HAVE_SYS_MMAN_H
 #include <sys/mman.h>
 #endif
-#include <wine/windef.h>
-#include <wine/winbase.h>
-#include <wine/winerror.h>
-#include <wine/heap.h>
-#include <wine/pe_image.h>
-#include <wine/module.h>
-#include <wine/debugtools.h>
+#include "windef.h"
+#include "winbase.h"
+#include "winerror.h"
+#include "heap.h"
+#include "pe_image.h"
+#include "module.h"
+#include "debugtools.h"
 #include "ext.h"
 #include "win32.h"
 
@@ -281,7 +280,7 @@ static DWORD fixup_imports( WINE_MODREF *wm )
      */
  
     for (i = 0, pe_imp = pem->pe_import; pe_imp->Name ; pe_imp++) {
-    	WINE_MODREF		*wmImp;
+    	/* WINE_MODREF		*wmImp; -- unused */
 	IMAGE_IMPORT_BY_NAME	*pe_name;
 	PIMAGE_THUNK_DATA	import_list,thunk_list;
  	char			*name = (char *) RVA(pe_imp->Name);
@@ -436,7 +435,7 @@ HMODULE PE_LoadImage( int handle, LPCSTR filename, WORD *version )
     IMAGE_NT_HEADERS *nt;
     IMAGE_SECTION_HEADER *pe_sec;
     IMAGE_DATA_DIRECTORY *dir;
-    BY_HANDLE_FILE_INFORMATION bhfi;
+    /* BY_HANDLE_FILE_INFORMATION bhfi; -- unused */
     int	i, rawsize, lowest_va, vma_size, file_size = 0;
     DWORD load_addr = 0, aoep, reloc = 0;
 //    struct get_read_fd_request *req = get_req_buffer();
@@ -646,8 +645,8 @@ HMODULE PE_LoadImage( int handle, LPCSTR filename, WORD *version )
             DWORD end = (pe_sec->SizeOfRawData & ~(page_size-1)) + page_size;
             if (end > pe_sec->Misc.VirtualSize) end = pe_sec->Misc.VirtualSize;
             TRACE("clearing %p - %p\n",
-                  RVA(pe_sec->VirtualAddress) + pe_sec->SizeOfRawData,
-                  RVA(pe_sec->VirtualAddress) + end );
+                  (char *)RVA(pe_sec->VirtualAddress) + pe_sec->SizeOfRawData,
+                  (char *)RVA(pe_sec->VirtualAddress) + end );
             memset( (char*)RVA(pe_sec->VirtualAddress) + pe_sec->SizeOfRawData, 0,
                     end - pe_sec->SizeOfRawData );
         }
@@ -696,7 +695,7 @@ WINE_MODREF *PE_CreateModule( HMODULE hModule,
     IMAGE_EXPORT_DIRECTORY *pe_export = NULL;
     IMAGE_RESOURCE_DIRECTORY *pe_resource = NULL;
     WINE_MODREF *wm;
-    int	result;
+    /* int	result; -- unused */
 
 
     
@@ -951,6 +950,7 @@ WIN_BOOL PE_InitDLL( WINE_MODREF *wm, DWORD type, LPVOID lpReserved )
     return retv;
 }
 
+#if 0
 static LPVOID
 _fixup_address(PIMAGE_OPTIONAL_HEADER opt,int delta,LPVOID addr) {
 	if (	((DWORD)addr>opt->ImageBase) &&
@@ -962,3 +962,4 @@ _fixup_address(PIMAGE_OPTIONAL_HEADER opt,int delta,LPVOID addr) {
 		
 		return addr;
 }
+#endif
