@@ -19,7 +19,7 @@
  *
  * Time stretch by a given factor, optionally preserving pitch
  *
- * $Id: stretch.c,v 1.7 2005/07/16 17:00:50 miguelfreitas Exp $
+ * $Id: stretch.c,v 1.8 2006/01/27 07:46:12 tmattern Exp $
  *
  */
 
@@ -647,7 +647,7 @@ static post_plugin_t *stretch_open_plugin(post_class_t *class_gen, int inputs,
   input_api->name = "parameters";
   input_api->type = XINE_POST_DATA_PARAMETERS;
   input_api->data = &post_api;
-  xine_list_append_content(this->post.input, input_api);
+  xine_list_push_back(this->post.input, input_api);
 
   this->post.xine_post.audio_input[0] = &port->new_port;
 
