@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_out_opengl.c,v 1.54 2005/09/25 00:44:04 miguelfreitas Exp $
+ * $Id: video_out_opengl.c,v 1.58 2006/06/20 01:07:58 dgp85 Exp $
  * 
  * video_out_opengl.c, OpenGL based interface for xine
  *
@@ -709,7 +709,10 @@ static void *getdladdr (const GLubyte *_funcName) {
   return res;
 
 #elif defined (__sun) || defined (__sgi)
-   static void *handle = dlopen (NULL, RTLD_LAZY);
+   static void *handle = NULL;
+   if (!handle) {
+     handle = dlopen (NULL, RTLD_LAZY);
+   }
    return dlsym (handle, funcName);
     
 #else /* all other Un*xes */
@@ -942,7 +945,7 @@ static int render_setup_fp_yuv (opengl_driver_t *this) {
   ret = render_setup_tex2d (this);
   if (! this->has_fragprog)
     return 0;
-  if (this->fprog == -1)
+  if (this->fprog == (GLuint)-1)
     this->glGenProgramsARB (1, &this->fprog);
   this->glBindProgramARB   (MYGL_FRAGMENT_PROGRAM_ARB, this->fprog);
   this->glProgramStringARB (MYGL_FRAGMENT_PROGRAM_ARB,
@@ -1982,7 +1985,7 @@ static void *opengl_init_class (xine_t *xine, void *visual_gen) {
 }
 
 
-static vo_info_t vo_info_opengl = {
+static const vo_info_t vo_info_opengl = {
   7,                    /* priority    */
   XINE_VISUAL_TYPE_X11  /* visual type */
 };
@@ -1992,7 +1995,7 @@ static vo_info_t vo_info_opengl = {
  * exported plugin catalog entry
  */
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */  
   { PLUGIN_VIDEO_OUT, 21, "opengl", XINE_VERSION_CODE, &vo_info_opengl, opengl_init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
