@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_out_sdl.c,v 1.44 2005/09/25 00:44:04 miguelfreitas Exp $
+ * $Id: video_out_sdl.c,v 1.47 2006/06/02 22:18:58 dsalt Exp $
  *
  * video_out_sdl.c, Simple DirectMedia Layer
  *
@@ -47,7 +47,8 @@
 #include <string.h>
 #include <inttypes.h>
 #include <math.h>
-#if defined (__FreeBSD__)
+
+#ifdef HAVE_SDL11_SDL_H
 # include <SDL11/SDL.h>
 #else
 # include <SDL.h>
@@ -602,12 +603,12 @@ static void *init_class (xine_t *xine, void *visual_gen) {
   return this;
 }
 
-static vo_info_t vo_info_sdl = {
+static const vo_info_t vo_info_sdl = {
   4,                    /* priority */
   XINE_VISUAL_TYPE_X11, /* visual type supported by this plugin */
 };
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_VIDEO_OUT, 21, "sdl", XINE_VERSION_CODE, &vo_info_sdl, init_class },
   { PLUGIN_NONE, 0, "" , 0 , NULL, NULL}
