@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_out_xv.c,v 1.214 2005/09/25 00:44:04 miguelfreitas Exp $
+ * $Id: video_out_xv.c,v 1.218 2006/06/02 22:18:59 dsalt Exp $
  *
  * video_out_xv.c, X11 video extension interface for xine
  *
@@ -616,7 +616,7 @@ static void xv_compute_output_size (xv_driver_t *this) {
   /* onefield_xv divide by 2 the number of lines */
   if (this->deinterlace_enabled
       && (this->deinterlace_method == DEINTERLACE_ONEFIELDXV)
-      && (this->cur_frame->format == XINE_IMGFMT_YV12)) {
+      && this->cur_frame && (this->cur_frame->format == XINE_IMGFMT_YV12)) {
     this->sc.displayed_height  = this->sc.displayed_height / 2 - 1;
     this->sc.displayed_yoffset = this->sc.displayed_yoffset / 2;
   }
@@ -1025,15 +1025,16 @@ static void xv_store_port_attribute(xv_driver_t *this, char *name) {
   XvGetPortAttribute (this->display, this->xv_port, atom, &attr->value);
   XUnlockDisplay(this->display);
   
-  xine_list_append_content (this->port_attributes, attr);
+  xine_list_push_back (this->port_attributes, attr);
 }
 
 static void xv_restore_port_attributes(xv_driver_t *this) {
   Atom                 atom;
-  xv_portattribute_t  *attr;
+  xine_list_iterator_t ite;
   
-  while ((attr = xine_list_first_content(this->port_attributes)) != NULL) {
-    xine_list_delete_current (this->port_attributes);
+  while ((ite = xine_list_front(this->port_attributes)) != NULL) {
+    xv_portattribute_t *attr = xine_list_get_value(this->port_attributes, ite);
+    xine_list_remove (this->port_attributes, ite);
   
     XLockDisplay(this->display);
     atom = XInternAtom (this->display, attr->name, False);
@@ -1048,7 +1049,7 @@ static void xv_restore_port_attributes(xv_driver_t *this) {
   XSync(this->display, False);
   XUnlockDisplay(this->display);
  
-  xine_list_free( this->port_attributes );
+  xine_list_delete( this->port_attributes );
 }
 
 static void xv_dispose (vo_driver_t *this_gen) {
@@ -1596,7 +1597,7 @@ static void *init_class (xine_t *xine, void *visual_gen) {
   return this;
 }
 
-static vo_info_t vo_info_xv = {
+static const vo_info_t vo_info_xv = {
   9,                    /* priority    */
   XINE_VISUAL_TYPE_X11  /* visual type */
 };
@@ -1605,7 +1606,7 @@ static vo_info_t vo_info_xv = {
  * exported plugin catalog entry
  */
 
-plugin_info_t xine_plugin_info[] = {
+const plugin_info_t xine_plugin_info[] = {
   /* type, API, "name", version, special_info, init_function */
   { PLUGIN_VIDEO_OUT, 21, "xv", XINE_VERSION_CODE, &vo_info_xv, init_class },
   { PLUGIN_NONE, 0, "", 0, NULL, NULL }
