@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: configfile.c,v 1.78 2005/07/21 02:51:14 miguelfreitas Exp $
+ * $Id: configfile.c,v 1.80 2006/06/20 00:35:07 dgp85 Exp $
  *
  * config object (was: file) management - implementation
  *
@@ -964,12 +964,12 @@ void xine_config_save (xine_t *xine, const char *filename) {
     f_backup = fopen(temp, "w");
     f_config = fopen(filename, "r");
     
-    if (f_config && f_backup && (stat(filename, &config_stat) == 0) && (config_stat.st_size > 0)) {
+    if (f_config && f_backup && (stat(filename, &config_stat) == 0)) {
       char    *buf = NULL;
       size_t   rlen;
       
       buf = (char *) xine_xmalloc(config_stat.st_size + 1);
-      if((rlen = fread(buf, 1, config_stat.st_size, f_config)) && (rlen == config_stat.st_size)) {
+      if((rlen = fread(buf, 1, config_stat.st_size, f_config)) && ((off_t)rlen == config_stat.st_size)) {
 	(void) fwrite(buf, 1, rlen, f_backup);
       }
       free(buf);
