@@ -22,7 +22,7 @@
  * The goal of this input plugin is to reduce 
  * the number of calls to the real input plugin.
  *
- * $Id: input_cache.c,v 1.8 2005/10/14 21:02:16 miguelfreitas Exp $
+ * $Id: input_cache.c,v 1.11 2006/06/20 00:35:07 dgp85 Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,7 +45,7 @@ typedef struct {
   input_plugin_t   *main_input_plugin; /* original input plugin */
   xine_stream_t    *stream;
 
-  uint8_t           buf[BUFFER_SIZE];
+  char              buf[BUFFER_SIZE];
   int               buf_len;
   int               buf_pos;
 
@@ -73,7 +73,7 @@ static off_t cache_plugin_read(input_plugin_t *this_gen, char *buf, off_t len) {
   if (len <= (this->buf_len - this->buf_pos)) {
     /* all bytes are in the buffer */
     switch (len) {
-#if !(defined(sparc) || defined(__sparc__))
+#if !(defined(sparc) || defined(__sparc__) || defined __ia64__)
       case 8:
         *((uint64_t *)buf) = *(uint64_t *)(&(this->buf[this->buf_pos]));
         break;
@@ -258,7 +258,7 @@ static off_t cache_plugin_seek_time(input_plugin_t *this_gen, int time_offset, i
   cache_input_plugin_t *this = (cache_input_plugin_t *)this_gen;
   off_t cur_pos;
   
-  lprintf("time_offset: %ld, origin: %d\n", time_offset, origin);
+  lprintf("time_offset: %d, origin: %d\n", time_offset, origin);
   this->seek_call++;
 
   cur_pos = this->main_input_plugin->seek_time(this->main_input_plugin, time_offset, origin);
