@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2006 the xine project
  *
  * This file is part of xine, a free video player.
  *
@@ -29,7 +29,7 @@
  * - it's possible speeder saving streams in the xine without playing:
  *     xine stream_mrl#save:file.raw\;noaudio\;novideo
  *
- * $Id: input_rip.c,v 1.27.2.2 2005/04/20 17:21:16 mroi Exp $
+ * $Id: input_rip.c,v 1.31 2006/06/20 00:35:07 dgp85 Exp $
  */
 
 /* TODO:
@@ -105,6 +105,8 @@ static off_t rip_plugin_read(input_plugin_t *this_gen, char *buf, off_t len) {
 
   lprintf("reading %lld bytes (curpos = %lld, savepos = %lld)\n", len, this->curpos, this->savepos);
 
+  if (len < 0) return -1;
+
   /* compute sizes and copy data from preview */
   if (this->curpos < this->preview_size && this->preview) {
     npreview = this->preview_size - this->curpos;
@@ -212,7 +214,7 @@ static buf_element_t *rip_plugin_read_block(input_plugin_t *this_gen, fifo_buffe
 
   lprintf("reading %lld bytes (curpos = %lld, savepos = %lld) (block)\n", todo, this->curpos, this->savepos);
 
-  if (!todo) return NULL;
+  if (todo <= 0) return NULL;
 
   /* compute sizes and copy data from preview */
   if (this->curpos < this->preview_size && this->preview) {
@@ -333,7 +335,7 @@ static off_t rip_plugin_seek(input_plugin_t *this_gen, off_t offset, int origin)
   char buffer[SCRATCH_SIZE];
   rip_input_plugin_t *this = (rip_input_plugin_t *)this_gen;
   uint32_t blocksize;
-  off_t newpos, toread, reqpos, pos;
+  off_t newpos, reqpos, pos;
   struct timeval time1, time2;
   double interval = 0;
 
@@ -409,7 +411,7 @@ static off_t rip_plugin_seek(input_plugin_t *this_gen, off_t offset, int origin)
       else
         break;
     } else {
-      toread = newpos - this->curpos;
+      size_t toread = newpos - this->curpos;
       if( toread > sizeof(buffer) )
         toread = sizeof(buffer);
 
