@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2000-2001 the xine project
+ * Copyright (C) 2000-2003 the xine project
  * 
- * This file is part of xine, a unix video player.
+ * This file is part of xine, a free video player.
  * 
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,22 +18,61 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
  * OSD stuff (text and graphic primitives)
- * $Id: osd.h,v 1.9 2002/03/14 13:57:15 miguelfreitas Exp $
+ * $Id: osd.h,v 1.26 2005/09/25 00:44:04 miguelfreitas Exp $
  */
 
 #ifndef HAVE_OSD_H
 #define HAVE_OSD_H
 
-#include "video_overlay.h"
-#ifdef __OSD_C__
-#include "video_out/alphablend.h"
+#ifdef HAVE_ICONV
+#  include <iconv.h>
 #endif
-typedef struct osd_object_s osd_object_t;
 
+#ifdef XINE_COMPILE
+#  include "video_overlay.h"
+#  ifdef __OSD_C__
+#    include "alphablend.h"
+#  endif
+#else
+#  include <xine/video_overlay.h>
+#endif
+
+typedef struct osd_object_s osd_object_t;
 typedef struct osd_renderer_s osd_renderer_t;
 typedef struct osd_font_s osd_font_t;
+typedef struct osd_ft2context_s osd_ft2context_t;
+
+struct osd_object_s {
+  osd_object_t *next;
+  osd_renderer_t *renderer;
+
+  int width, height;    /* work area dimentions */
+  uint8_t *area;        /* work area */
+  int display_x,display_y;  /* where to display it in screen */
+  
+  /* clipping box inside work area */
+  int x1, y1;
+  int x2, y2;
+  
+  uint32_t color[OVL_PALETTE_SIZE];	/* color lookup table  */
+  uint8_t trans[OVL_PALETTE_SIZE];	/* mixer key table */
+
+  int32_t handle;
+
+#ifdef HAVE_ICONV
+  iconv_t cd;                           /* iconv handle of encoding */
+  char *encoding;                       /* name of encoding */
+#endif
+  
+  osd_font_t *font;
+  osd_ft2context_t *ft2;
+};
+
+/* this one is public */
+struct xine_osd_s {
+  osd_object_t osd;
+};
 
-/* WARNING: this should be kept in sync with include/xine.h.tmpl.in */
 struct osd_renderer_s {
 
   /*
@@ -64,14 +103,19 @@ struct osd_renderer_s {
    */
   int (*hide) (osd_object_t *osd, int64_t vpts );
 
-  /*
+  /* 
+   * draw point.
+   */
+  void (*point) (osd_object_t *osd, int x, int y, int color);
+       
+       /*
    * Bresenham line implementation on osd object
    */
   void (*line) (osd_object_t *osd,
 		int x1, int y1, int x2, int y2, int color );
   
   /*
-   * filled retangle
+   * filled rectangle
    */
   void (*filled_rect) (osd_object_t *osd,
 		       int x1, int y1, int x2, int y2, int color );
@@ -79,7 +123,7 @@ struct osd_renderer_s {
   /*
    * set palette (color and transparency)
    */
-  void (*set_palette) (osd_object_t *osd, uint32_t *color, uint8_t *trans );
+  void (*set_palette) (osd_object_t *osd, const uint32_t *color, const uint8_t *trans );
 
   /*
    * set on existing text palette 
@@ -109,11 +153,18 @@ struct osd_renderer_s {
    * set the font of osd object
    */
 
-  int (*set_font) (osd_object_t *osd, char *fontname, int size);
-
+  int (*set_font) (osd_object_t *osd, const char *fontname, int size);
 
   /*
-   * render text on x,y position (8 bits version)
+   * set encoding of text
+   *
+   * NULL ... no conversion (iso-8859-1)
+   * ""   ... locale encoding
+   */
+  int (*set_encoding) (osd_object_t *osd, const char *encoding);
+
+  /*
+   * render text in current encoding on x,y position
    * no \n yet
    *
    * The text is assigned the colors starting at the index specified by
@@ -122,12 +173,12 @@ struct osd_renderer_s {
    * Use OSD_TEXT1, OSD_TEXT2, ... for some preasssigned color indices.
    */
   int (*render_text) (osd_object_t *osd, int x1, int y1, 
-		      char *text, int color_base);
+		      const char *text, int color_base);
 
   /*
    * get width and height of how text will be renderized
    */
-  int (*get_text_size) (osd_object_t *osd, char *text, 
+  int (*get_text_size) (osd_object_t *osd, const char *text, 
 			int *width, int *height);
 
   /* 
@@ -142,23 +193,41 @@ struct osd_renderer_s {
    */
   void (*clear) (osd_object_t *osd );
     
+  /*
+   * paste a bitmap with optional palette mapping
+   */
+  void (*draw_bitmap) (osd_object_t *osd, uint8_t *bitmap,
+		       int x1, int y1, int width, int height,
+		       uint8_t *palette_map);
+
+  /*
+   * send the osd to be displayed (unscaled) at given pts (0=now)
+   * the object is not changed. there may be subsequent drawing  on it.
+   * overlay is blended at output (screen) resolution.
+   */
+  int (*show_unscaled) (osd_object_t *osd, int64_t vpts );
+
+  /*
+   * see xine.h for defined XINE_OSD_CAP_ values.
+   */
+  uint32_t (*get_capabilities) (osd_object_t *osd);
+  
   /* private stuff */
 
   pthread_mutex_t             osd_mutex;
-  video_overlay_instance_t   *video_overlay;
   video_overlay_event_t       event;
   osd_object_t               *osds;          /* instances of osd */
   osd_font_t                 *fonts;         /* loaded fonts */
   int                        textpalette;    /* default textpalette */
   
-  config_values_t           *config;
+  xine_stream_t              *stream;
 
 };
 
 /*
  *   initialize the osd rendering engine
  */
-osd_renderer_t *osd_renderer_init( video_overlay_instance_t *video_overlay, config_values_t *config );
+osd_renderer_t *_x_osd_renderer_init( xine_stream_t *stream );
 
 
 /*
@@ -228,59 +297,59 @@ static char *textpalettes_str[NUMBER_OF_TEXT_PALETTES+1] = {
 static clut_t textpalettes_color[NUMBER_OF_TEXT_PALETTES][TEXT_PALETTE_SIZE] = {
 /* white, black border, transparent */
   {
-    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), //0
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //1
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //2
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //3
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //4
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //5
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //6
-    CLUT_Y_CR_CB_INIT(0x40, 0x80, 0x80), //7
-    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), //8
-    CLUT_Y_CR_CB_INIT(0xc0, 0x80, 0x80), //9
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //10
+    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), /*0*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*1*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*2*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*3*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*4*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*5*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*6*/
+    CLUT_Y_CR_CB_INIT(0x40, 0x80, 0x80), /*7*/
+    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), /*8*/
+    CLUT_Y_CR_CB_INIT(0xc0, 0x80, 0x80), /*9*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*10*/
   },
   /* white, no border, transparent */
   {
-    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), //0
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //1
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //2
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //3
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //4
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //5
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //6
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //7
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //8
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //9
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //10
+    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), /*0*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*1*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*2*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*3*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*4*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*5*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*6*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*7*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*8*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*9*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*10*/
   },
   /* white, no border, translucid */
   {
-    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), //0
-    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), //1
-    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), //2
-    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), //3
-    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), //4
-    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), //5
-    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), //6
-    CLUT_Y_CR_CB_INIT(0xa0, 0x80, 0x80), //7
-    CLUT_Y_CR_CB_INIT(0xc0, 0x80, 0x80), //8
-    CLUT_Y_CR_CB_INIT(0xe0, 0x80, 0x80), //9
-    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), //10
+    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), /*0*/
+    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), /*1*/
+    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), /*2*/
+    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), /*3*/
+    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), /*4*/
+    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), /*5*/
+    CLUT_Y_CR_CB_INIT(0x80, 0x80, 0x80), /*6*/
+    CLUT_Y_CR_CB_INIT(0xa0, 0x80, 0x80), /*7*/
+    CLUT_Y_CR_CB_INIT(0xc0, 0x80, 0x80), /*8*/
+    CLUT_Y_CR_CB_INIT(0xe0, 0x80, 0x80), /*9*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x80, 0x80), /*10*/
   },
   /* yellow, black border, transparent */
   {
-    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), //0
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //1
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //2
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //3
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //4
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //5
-    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), //6
-    CLUT_Y_CR_CB_INIT(0x40, 0x84, 0x60), //7
-    CLUT_Y_CR_CB_INIT(0xd0, 0x88, 0x40), //8
-    CLUT_Y_CR_CB_INIT(0xe0, 0x8a, 0x00), //9
-    CLUT_Y_CR_CB_INIT(0xff, 0x90, 0x00), //10
+    CLUT_Y_CR_CB_INIT(0x00, 0x00, 0x00), /*0*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*1*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*2*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*3*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*4*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*5*/
+    CLUT_Y_CR_CB_INIT(0x00, 0x80, 0x80), /*6*/
+    CLUT_Y_CR_CB_INIT(0x40, 0x84, 0x60), /*7*/
+    CLUT_Y_CR_CB_INIT(0x70, 0x88, 0x40), /*8*/
+    CLUT_Y_CR_CB_INIT(0xb0, 0x8a, 0x20), /*9*/
+    CLUT_Y_CR_CB_INIT(0xff, 0x90, 0x00), /*10*/
   },
 };
 
