@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2000-2004 the xine project
+ * Copyright (C) 2000-2005 the xine project
  *
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: video_decoder.c,v 1.158 2005/04/19 17:42:30 hadess Exp $
+ * $Id: video_decoder.c,v 1.160 2005/10/30 02:18:35 miguelfreitas Exp $
  *
  */
 
@@ -153,8 +153,9 @@ static void *video_decoder_loop (void *stream_gen) {
       
       running_ticket->release(running_ticket, 0);
       
-      stream->metronom->handle_video_discontinuity (stream->metronom, 
-						    DISC_STREAMSTART, 0);
+      if( !stream->gapless_switch )
+        stream->metronom->handle_video_discontinuity (stream->metronom, 
+						      DISC_STREAMSTART, 0);
       
       buftype_unknown = 0;
       break;
@@ -189,7 +190,7 @@ static void *video_decoder_loop (void *stream_gen) {
           stream->video_decoder_plugin->flush (stream->video_decoder_plugin);
         running_ticket->release(running_ticket, 0);
       }
-      
+
       /*
        * wait the output fifos to run dry before sending the notification event
        * to the frontend. this test is only valid if there is only a single
@@ -203,7 +204,7 @@ static void *video_decoder_loop (void *stream_gen) {
         num_streams = stream->video_out->get_property(stream->video_out, VO_PROP_NUM_STREAMS);
         running_ticket->release(running_ticket, 0);
         
-        if( num_bufs > 0 && num_streams == 1 )
+        if( num_bufs > 0 && num_streams == 1 && !stream->early_finish_event )
           xine_usec_sleep (10000);
         else
           break;
@@ -220,7 +221,7 @@ static void *video_decoder_loop (void *stream_gen) {
 
       pthread_cond_broadcast (&stream->counter_changed);
 
-      if (stream->audio_thread) {
+      if (stream->audio_thread_created) {
 
         while (stream->finished_count_video > stream->finished_count_audio) {
           struct timeval tv;
@@ -500,7 +501,8 @@ void _x_video_decoder_init (xine_stream_t *stream) {
     pth_params.sched_priority = sched_get_priority_min(SCHED_OTHER);
     pthread_attr_setschedparam(&pth_attrs, &pth_params);
     pthread_attr_setscope(&pth_attrs, PTHREAD_SCOPE_SYSTEM);
-    
+
+    stream->video_thread_created = 1;
     if ((err = pthread_create (&stream->video_thread,
                                &pth_attrs, video_decoder_loop, stream)) != 0) {
       fprintf (stderr, "video_decoder: can't create new thread (%s)\n",
@@ -519,7 +521,7 @@ void _x_video_decoder_shutdown (xine_stream_t *stream) {
 
   lprintf ("shutdown...\n");
 
-  if (stream->video_thread) {
+  if (stream->video_thread_created) {
 
     /* stream->video_fifo->clear(stream->video_fifo); */
 
@@ -533,6 +535,7 @@ void _x_video_decoder_shutdown (xine_stream_t *stream) {
     lprintf ("shutdown...3\n");
 
     pthread_join (stream->video_thread, &p);
+    stream->video_thread_created = 0;
 
     lprintf ("shutdown...4\n");
 
