@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2005 the xine project
+ * Copyright (C) 2000-2006 the xine project
  * 
  * This file is part of xine, a free video player.
  * 
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xine.c,v 1.319 2005/10/30 02:18:35 miguelfreitas Exp $
+ * $Id: xine.c,v 1.324 2006/07/03 10:55:37 dgp85 Exp $
  */
 
 /*
@@ -36,6 +36,7 @@
 #include <stdlib.h>
 #include <pthread.h>
 #include <stdarg.h>
+#include <stdio.h>
 #if defined (__linux__)
 #include <endian.h>
 #elif defined (__FreeBSD__)
@@ -294,7 +295,11 @@ void xine_stop (xine_stream_t *stream) {
 
   pthread_mutex_lock (&stream->frontend_lock);
 
+  /* make sure that other threads cannot change the speed, especially pauseing the stream */
+  pthread_mutex_lock(&stream->speed_change_lock);
   stream->ignore_speed_change = 1;
+  pthread_mutex_unlock(&stream->speed_change_lock);
+
   stream->xine->port_ticket->acquire(stream->xine->port_ticket, 1);
 
   if (stream->audio_out)
@@ -333,7 +338,11 @@ static void close_internal (xine_stream_t *stream) {
   }
 
   if( !stream->gapless_switch ) {
+    /* make sure that other threads cannot change the speed, especially pauseing the stream */
+    pthread_mutex_lock(&stream->speed_change_lock);
     stream->ignore_speed_change = 1;
+    pthread_mutex_unlock(&stream->speed_change_lock);
+
     stream->xine->port_ticket->acquire(stream->xine->port_ticket, 1);
   
     if (stream->audio_out)
@@ -530,6 +539,7 @@ xine_stream_t *xine_stream_new (xine_t *this,
   pthread_mutex_init (&stream->first_frame_lock, NULL);
   pthread_cond_init  (&stream->first_frame_reached, NULL);
   pthread_mutex_init (&stream->current_extra_info_lock, NULL);
+  pthread_mutex_init (&stream->speed_change_lock, NULL);
 
   /* warning: frontend_lock is a recursive mutex. it must NOT be
    * used with neither pthread_cond_wait() or pthread_cond_timedwait()
@@ -585,7 +595,7 @@ xine_stream_t *xine_stream_new (xine_t *this,
    * register stream
    */
 
-  xine_list_append_content (this->streams, stream);
+  xine_list_push_back (this->streams, stream);
 
   pthread_mutex_unlock (&this->streams_lock);
 
@@ -621,13 +631,14 @@ static void mrl_unescape(char *mrl) {
 
 void _x_flush_events_queues (xine_stream_t *stream) {
 
-  xine_event_queue_t *queue;
+  xine_list_iterator_t ite;
 
   pthread_mutex_lock (&stream->event_queues_lock);
 
   /* No events queue? */
-  for (queue = xine_list_first_content (stream->event_queues);
-       queue; queue = xine_list_next_content (stream->event_queues)) {
+  for (ite = xine_list_front (stream->event_queues);
+       ite; ite = xine_list_next (stream->event_queues, ite)) {
+    xine_event_queue_t *queue = xine_list_get_value(stream->event_queues, ite);
     pthread_mutex_lock (&queue->lock);
     pthread_mutex_unlock (&stream->event_queues_lock);
 
@@ -637,7 +648,7 @@ void _x_flush_events_queues (xine_stream_t *stream) {
      * currently executing their callback functions.
      */
     if (queue->listener_thread != NULL && !queue->callback_running) {
-      while (!xine_list_is_empty (queue->events)) {
+      while (!xine_list_empty (queue->events)) {
         pthread_cond_wait (&queue->events_processed, &queue->lock);
       }
     }
@@ -989,15 +1000,15 @@ static int open_internal (xine_stream_t *stream, const char *mrl) {
 	  if (retval == 0) {
 	    /* the option not found */
 	    xine_log(stream->xine, XINE_LOG_MSG, _("xine: error while parsing MRL\n"));
+	    stream->err = XINE_ERROR_MALFORMED_MRL;
+	    stream->status = XINE_STATUS_IDLE;
+	    free(config_entry);
+	    return 0;
 	  } else {
             /* not permitted to change from MRL */
             xine_log(stream->xine, XINE_LOG_MSG, _("xine: changing option '%s' from MRL isn't permitted\n"),
 	      config_entry);
 	  }
-          stream->err = XINE_ERROR_MALFORMED_MRL;
-          stream->status = XINE_STATUS_IDLE;
-	  free(config_entry);
-          return 0;
 	}
 	free(config_entry);
       }
@@ -1249,7 +1260,7 @@ int xine_eject (xine_stream_t *stream) {
 
 void xine_dispose_internal (xine_stream_t *stream) {
 
-  xine_stream_t *s;
+  xine_list_iterator_t *ite;
 
   lprintf("stream: %p\n", stream);
   pthread_mutex_destroy (&stream->info_mutex);
@@ -1266,12 +1277,9 @@ void xine_dispose_internal (xine_stream_t *stream) {
   stream->metronom->exit (stream->metronom);
 
   pthread_mutex_lock(&stream->xine->streams_lock);
-  for (s = xine_list_first_content(stream->xine->streams);
-       s; s = xine_list_next_content(stream->xine->streams)) {
-    if (s == stream) {
-      xine_list_delete_current (stream->xine->streams);
-      break;
-    }
+  ite = xine_list_find(stream->xine->streams, stream);
+  if (ite) {
+    xine_list_remove(stream->xine->streams, ite);
   }
   pthread_mutex_unlock(&stream->xine->streams_lock);
 
@@ -1327,7 +1335,7 @@ void xine_exit (xine_t *this) {
   _x_dispose_plugins (this);
 
   if(this->streams) {
-    xine_list_free(this->streams);
+    xine_list_delete(this->streams);
     pthread_mutex_destroy(&this->streams_lock);
   }
 
@@ -1454,13 +1462,16 @@ static void config_save_cb (void *this_gen, xine_cfg_entry_t *entry) {
        strcmp(entry->str_value, xine_get_homedir()) == 0 ||
        strcmp(entry->str_value, homedir_trail_slash) == 0)) {
     xine_stream_t *stream;
+    xine_list_iterator_t ite;
     
     xine_log(this, XINE_LOG_MSG,
 	     _("xine: The specified save_dir \"%s\" might be a security risk.\n"), entry->str_value);
     
     pthread_mutex_lock(&this->streams_lock);
-    if ((stream = (xine_stream_t *)xine_list_first_content(this->streams)))
+    if ( (ite = xine_list_front(this->streams)) ) {
+      stream = xine_list_get_value(this->streams, ite);
       _x_message(stream, XINE_MSG_SECURITY, _("The specified save_dir might be a security risk."), NULL);
+    }
     pthread_mutex_unlock(&this->streams_lock);
   }
   
@@ -1535,6 +1546,18 @@ void xine_init (xine_t *this) {
 	"messed up xine."),
       XINE_CONFIG_SECURITY, NULL, this);
 
+  /*
+   * timeout for network I/O to avoid freezes
+   */
+  this->config->register_num(this->config,
+      "media.network.timeout", 30,
+      _("Timeout for network stream reading (in seconds)"),
+      _("Specifies the timeout when reading from network streams, in seconds."
+	"Too low values might stop streaming when the source is slow or the"
+	"bandwidth is occupied, too high values will freeze the player if the"
+	"connection is lost."),
+      0, NULL, this);
+
   /*
    * keep track of all opened streams
    */
@@ -1639,18 +1662,20 @@ int xine_get_status (xine_stream_t *stream) {
  */
 
 void _x_set_fine_speed (xine_stream_t *stream, int speed) {
+  pthread_mutex_lock(&stream->speed_change_lock);
 
-  if (stream->ignore_speed_change)
-    return;
-
-  if (speed <= XINE_SPEED_PAUSE)
-    speed = XINE_SPEED_PAUSE;
-
-  xprintf (stream->xine, XINE_VERBOSITY_DEBUG, "set_speed %d\n", speed);
-  set_speed_internal (stream, speed);
+  if (!stream->ignore_speed_change)
+  {
+    if (speed <= XINE_SPEED_PAUSE)
+      speed = XINE_SPEED_PAUSE;
   
-  if (stream->slave && (stream->slave_affection & XINE_MASTER_SLAVE_SPEED))
-    set_speed_internal (stream->slave, speed);
+    xprintf (stream->xine, XINE_VERBOSITY_DEBUG, "set_speed %d\n", speed);
+    set_speed_internal (stream, speed);
+    
+    if (stream->slave && (stream->slave_affection & XINE_MASTER_SLAVE_SPEED))
+      set_speed_internal (stream->slave, speed);
+  }
+  pthread_mutex_unlock(&stream->speed_change_lock);
 }
 
 int _x_get_fine_speed (xine_stream_t *stream) {
