@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2000-2001 the xine project
+ * Copyright (C) 2000-2005 the xine project
  * 
- * This file is part of xine, a unix video player.
+ * This file is part of xine, a free video player.
  * 
  * xine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
  *
- * $Id: xineintl.h,v 1.4 2002/07/31 22:36:35 f1rmb Exp $
+ * $Id: xineintl.h,v 1.9 2005/02/19 13:11:53 valtri Exp $
  *
  */
 
@@ -32,21 +32,19 @@ extern "C" {
 
 #ifdef ENABLE_NLS
 #    include <libintl.h>
-#    define _(String) dgettext ("xine-lib", String)
+#    define _(String) dgettext (XINE_TEXTDOMAIN, String)
 #    ifdef gettext_noop
 #        define N_(String) gettext_noop (String)
 #    else
 #        define N_(String) (String)
 #    endif
-#    ifndef HAVE_NGETTEXT
-#        define ngettext(Singular, Plural, IsPlural) (Singular)
-#    endif
 #else
 /* Stubs that do something close enough.  */
 #    define textdomain(String) (String)
 #    define gettext(String) (String)
 #    define dgettext(Domain,Message) (Message)
 #    define dcgettext(Domain,Message,Type) (Message)
+#    define ngettext(Singular, Plural, IsPlural) (Singular)
 #    define bindtextdomain(Domain,Directory) (Domain)
 #    define _(String) (String)
 #    define N_(String) (String)
